Python Pix
==========================

[![pypi](https://img.shields.io/pypi/v/google-auth.svg)](https://pypi.python.org/pypi/google-auth)
[![Build Status](https://travis-ci.com/dyohan9/python-pix.svg?branch=master)](https://travis-ci.com/bothub-it/bothub-engine)
[![Python Version](https://img.shields.io/badge/python-3.6%20%7C%203.7%20%7C%203.8-blue.svg)](https://www.python.org/)
[![License GPL-3.0](https://img.shields.io/badge/license-%20GPL--3.0-yellow.svg)](https://github.com/bothub-it/bothub-engine/blob/master/LICENSE)


This library automates the creation of Pix keys

Installing
----------

You can install using [pip](https://pip.pypa.io/en/stable/):

    $ pip install pypix

### Supported Python Versions

Python \>= 3.6

### Deprecated Python Versions

Python == 2.7. Python 2.7 support will be removed on January 1, 2020.

Current Maintainers
-------------------

-   [@dyohan9](https://github.com/dyohan9) (Daniel Yohan)

Authors
-------

-   [@dyohan9](https://github.com/dyohan9) (Daniel Yohan)

Contributing
------------

Contributions to this library are always welcome and highly encouraged.

See
[CONTRIBUTING.md](https://github.com/dyohan9/python-pix/blob/master/CONTRIBUTING.md)
for more information on how to get started.

License
-------

GPL-3.0 License - See [the
LICENSE](https://github.com/dyohan9/python-pix/blob/master/LICENSE)
for more information.
